==> tuia-advert-center-api-1.5.9-20180715.070155-9-sources.jar: cn/com/duiba/tuia/core/api/dto/advert/AppApplyAdvertRspDto.java <==
package cn.com.duiba.tuia.core.api.dto.advert;

import java.math.BigDecimal;
import java.util.List;

/**
 * Created by huangch on 2018/4/9 21:52
 * description:
 *
 * @since JDK 1.6
 */
public class AppApplyAdvertRspDto {

    //申请的主键ID
    private Long applyId;

    //申请时间
    private String applyDate;

    //应用id
    private Long appId;

    //应用名称
    private String appName;

    //应用标签
    private String appTradeTag;

    //申请的应用广告位列表
    private List<String> applySlotList;

    //申请的广告列表
    private List<IdNameDto> applyAdvertList;

    //广告近7日平均cvr
    private BigDecimal nearlyWeekCvr;

    //广告预估cvr
    private BigDecimal forecastCvr;

    //媒体昨日发券量
    private Long yesterLaunchCount;

    //应用昨日CVR
    private String yesterAppCvr;

    //媒体来源，1-推啊，2-兑吧
    private Integer appSource;

    //申请状态，1-申请中，2-审核通过，3-审核拒绝
    private Integer applyStatus;

    //拒绝理由
    private String refuseReason;

    public BigDecimal getNearlyWeekCvr() {
        return nearlyWeekCvr;
    }

    public void setNearlyWeekCvr(BigDecimal nearlyWeekCvr) {
        this.nearlyWeekCvr = nearlyWeekCvr;
    }

    public BigDecimal getForecastCvr() {
        return forecastCvr;
    }

    public void setForecastCvr(BigDecimal forecastCvr) {
        this.forecastCvr = forecastCvr;
    }

    public Long getApplyId() {
        return applyId;
    }

    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }

    public String getApplyDate() {
        return applyDate;
    }

    public void setApplyDate(String applyDate) {
        this.applyDate = applyDate;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getAppName() {
        return appName;
    }

    public void setAppName(String appName) {
        this.appName = appName;
    }

    public String getAppTradeTag() {
        return appTradeTag;
    }

    public void setAppTradeTag(String appTradeTag) {
        this.appTradeTag = appTradeTag;
    }

    public List<String> getApplySlotList() {
        return applySlotList;
    }

    public void setApplySlotList(List<String> applySlotList) {
        this.applySlotList = applySlotList;
    }

    public List<IdNameDto> getApplyAdvertList() {
        return applyAdvertList;
    }

    public void setApplyAdvertList(List<IdNameDto> applyAdvertList) {
        this.applyAdvertList = applyAdvertList;
    }

    public Long getYesterLaunchCount() {
        return yesterLaunchCount;
    }

    public void setYesterLaunchCount(Long yesterLaunchCount) {
        this.yesterLaunchCount = yesterLaunchCount;
    }

    public String getYesterAppCvr() {
        return yesterAppCvr;
    }

    public void setYesterAppCvr(String yesterAppCvr) {
        this.yesterAppCvr = yesterAppCvr;
    }

    public Integer getAppSource() {
        return appSource;
    }

    public void setAppSource(Integer appSource) {
        this.appSource = appSource;
    }

    public Integer getApplyStatus() {
        return applyStatus;
    }

    public void setApplyStatus(Integer applyStatus) {
        this.applyStatus = applyStatus;
    }

    public String getRefuseReason() {
        return refuseReason;
    }

    public void setRefuseReason(String refuseReason) {
        this.refuseReason = refuseReason;
    }
}

==> tuia-advert-center-api-1.5.9-20180809.032225-33-sources.jar: cn/com/duiba/tuia/core/api/dto/advert/AppApplyAdvertRspDto.java <==
package cn.com.duiba.tuia.core.api.dto.advert;

import java.math.BigDecimal;
import java.util.List;

/**
 * Created by huangch on 2018/4/9 21:52
 * description:
 *
 * @since JDK 1.6
 */
public class AppApplyAdvertRspDto {

    //申请的主键ID
    private Long applyId;

    //申请时间
    private String applyDate;

    //应用id
    private Long appId;

    //应用名称
    private String appName;

    //应用标签
    private String appTradeTag;

    //申请的应用广告位列表
    private List<String> applySlotList;

    //申请的广告位ID列表
    private String slotIds;

    //申请的广告列表
    private List<IdNameDto> applyAdvertList;

    //广告近7日平均cvr
    private BigDecimal nearlyWeekCvr;

    //广告预估cvr
    private BigDecimal forecastCvr;

    //媒体昨日发券量
    private Long yesterLaunchCount;

    //应用昨日CVR
    private String yesterAppCvr;

    //媒体来源，1-推啊，2-兑吧
    private Integer appSource;

    //申请状态，1-申请中，2-审核通过，3-审核拒绝
    private Integer applyStatus;

    //申请的配置列表
    private List<String> orientationPackageList;

    //拒绝理由
    private String refuseReason;

    public List<String> getOrientationPackageList() {
        return orientationPackageList;
    }

    public void setOrientationPackageList(List<String> orientationPackageList) {
        this.orientationPackageList = orientationPackageList;
    }

    public String getSlotIds() {
        return slotIds;
    }

    public void setSlotIds(String slotIds) {
        this.slotIds = slotIds;
    }

    public BigDecimal getNearlyWeekCvr() {
        return nearlyWeekCvr;
    }

    public void setNearlyWeekCvr(BigDecimal nearlyWeekCvr) {
        this.nearlyWeekCvr = nearlyWeekCvr;
    }

    public BigDecimal getForecastCvr() {
        return forecastCvr;
    }

    public void setForecastCvr(BigDecimal forecastCvr) {
        this.forecastCvr = forecastCvr;
    }

    public Long getApplyId() {
        return applyId;
    }

    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }

    public String getApplyDate() {
        return applyDate;
    }

    public void setApplyDate(String applyDate) {
        this.applyDate = applyDate;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getAppName() {
        return appName;
    }

    public void setAppName(String appName) {
        this.appName = appName;
    }

    public String getAppTradeTag() {
        return appTradeTag;
    }

    public void setAppTradeTag(String appTradeTag) {
        this.appTradeTag = appTradeTag;
    }

    public List<String> getApplySlotList() {
        return applySlotList;
    }

    public void setApplySlotList(List<String> applySlotList) {
        this.applySlotList = applySlotList;
    }

    public List<IdNameDto> getApplyAdvertList() {
        return applyAdvertList;
    }

    public void setApplyAdvertList(List<IdNameDto> applyAdvertList) {
        this.applyAdvertList = applyAdvertList;
    }

    public Long getYesterLaunchCount() {
        return yesterLaunchCount;
    }

    public void setYesterLaunchCount(Long yesterLaunchCount) {
        this.yesterLaunchCount = yesterLaunchCount;
    }

    public String getYesterAppCvr() {
        return yesterAppCvr;
    }

    public void setYesterAppCvr(String yesterAppCvr) {
        this.yesterAppCvr = yesterAppCvr;
    }

    public Integer getAppSource() {
        return appSource;
    }

    public void setAppSource(Integer appSource) {
        this.appSource = appSource;
    }

    public Integer getApplyStatus() {
        return applyStatus;
    }

    public void setApplyStatus(Integer applyStatus) {
        this.applyStatus = applyStatus;
    }

    public String getRefuseReason() {
        return refuseReason;
    }

    public void setRefuseReason(String refuseReason) {
        this.refuseReason = refuseReason;
    }
}
